@@ -1,7 +1,7 @@
 #!/usr/bin/perl
 #
 # Automated Userinfo update script
-# $Id: Autoupdate.pl,v 1.11 2007/11/15 21:24:56 raeburn Exp $
+# $Id: Autoupdate.pl,v 1.13 2009/03/09 05:25:49 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -82,7 +82,7 @@
                     (my $insttypechg,@inststatuses) = 
                        &affiliations_check(\%userhash,$instusers{$uname});
                     if ($insttypechg) {
-                        my $inststatusstr = join(':',&escape(@inststatuses));
+                        my $inststatusstr = join(':',map { &escape($_) } (@inststatuses));
                         my %statushash = ( inststatus => $inststatusstr );
                         my $statusres = &Apache::lonnet::put('environment',\%statushash,$dom,$uname);
                     }
@@ -205,7 +205,7 @@ sub affiliations_check {
             @inststatuses = @{$insthashref->{'inststatus'}};
         }
     }
-    my @currstatuses = &unescape(split(/:/,$userhash->{'inststatus'}));
+    my @currstatuses = map { &unescape($_); } (split(/:/,$userhash->{'inststatus'}));
     foreach my $status (@inststatuses) {
         if (!grep/^\Q$status\E/,@currstatuses) {
             $insttypechg = 1;
