@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA 
 # edit mode helpers
 #
-# $Id: edit.pm,v 1.121 2008/12/10 21:59:43 raeburn Exp $
+# $Id: edit.pm,v 1.122 2009/02/18 07:06:12 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -1027,7 +1027,7 @@ sub entercoord {
 }
 
 sub deletecoorddata {
-    &Apache::lonnet::delenv("imagechoice\\.");
+    &Apache::lonnet::delenv('imagechoice.');
 }
 
 #----------------------------------------------------- browse
