@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # mutliple choice style responses
 #
-# $Id: radiobuttonresponse.pm,v 1.134 2008/08/08 16:37:13 bisitz Exp $
+# $Id: radiobuttonresponse.pm,v 1.134.2.1 2008/12/11 03:29:30 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -65,19 +65,21 @@ sub start_radiobuttonresponse {
     if ($target eq 'meta') {
 	$result=&Apache::response::meta_package_write('radiobuttonresponse');
     } elsif ($target eq 'edit' ) {
-	$result.=&Apache::edit::start_table($token).
-	    '<tr><td>'.&Apache::lonxml::description($token).
-	    &Apache::loncommon::help_open_topic('Radio_Response_Problems').
-	    "</td><td>Delete:".
-	    &Apache::edit::deletelist($target,$token)
-	    ."</td><td>&nbsp".&Apache::edit::end_row()
-	    .&Apache::edit::start_spanning_row();
+        $result.=&Apache::edit::start_table($token)
+           .'<tr><td>'.&Apache::lonxml::description($token)
+           .&Apache::loncommon::help_open_topic('Radio_Response_Problems')
+           .'</td>'
+           .'<td><span class="LC_nobreak">'.&mt('Delete?').' '
+           .&Apache::edit::deletelist($target,$token)
+           .'</span></td>'
+           .'<td>&nbsp;'.&Apache::edit::end_row()
+           .&Apache::edit::start_spanning_row();
 	$result.=
 	    &Apache::edit::text_arg('Max Number Of Shown Foils:','max',
-				    $token,'4').
-	    &Apache::edit::select_arg('Randomize Foil Order','randomize',
-				      ['yes','no'],$token).
-	    &Apache::edit::select_arg('Display Direction','direction',
+				    $token,'4').'&nbsp;'x 3 .
+	    &Apache::edit::select_arg('Randomize Foil Order:','randomize',
+				      ['yes','no'],$token).'&nbsp;'x 3 .
+	    &Apache::edit::select_arg('Display Direction:','direction',
 				      ['vertical','horizontal'],$token).
 				      &Apache::edit::end_row().
 				      &Apache::edit::start_spanning_row()."\n";
