@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA 
 # definition of tags that give a structure to a document
 #
-# $Id: structuretags.pm,v 1.431 2008/09/19 17:14:31 raeburn Exp $
+# $Id: structuretags.pm,v 1.434.2.1 2008/12/11 04:54:32 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -36,6 +36,7 @@ use Apache::File();
 use Apache::lonmenu;
 use Apache::lonlocal;
 use Apache::lonxml;
+use Apache::londefdef;
 use Apache::lonenc();
 use Time::HiRes qw( gettimeofday tv_interval );
 use lib '/home/httpd/lib/perl/';
@@ -74,7 +75,14 @@ sub start_tex {
     if ($target ne 'edit' && $target ne 'modified') {
 	my $bodytext=&Apache::lonxml::get_all_text("/tex",$parser,$style);
 	if ($target eq 'tex') {
-	    return $bodytext.' ';
+	    
+	    # If inside a table, occurrences of \\ must be removed;
+	    # else the table blows up.
+
+	    if (&Apache::londefdef::is_inside_of($tagstack, "table")) {
+		$bodytext =~ s/\\\\//g;
+	    }
+	    return $bodytext.'{}';
 	}
     } elsif ($target eq "edit" ) {
 	my $bodytext = 
@@ -148,8 +156,10 @@ sub page_start {
 
     $extra_head .= &homework_js();
 
-    unless ($env{'environment.wysiwygeditor'} eq 'on') {
-        $extra_head .= &Apache::lonhtmlcommon::dragmath_js();
+    if ($env{'environment.wysiwygeditor'} eq 'on') {
+	$extra_head .= &Apache::lonhtmlcommon::dragmath_js("FCKEditMathPopup");
+    } else {
+        $extra_head .= &Apache::lonhtmlcommon::dragmath_js("EditMathPopup");
     }
 
     my %body_args;
@@ -1285,7 +1295,7 @@ sub start_languageblock {
 	$target eq 'tex' || $target eq 'analyze' || $target eq 'webgrade') {
 	my $include = $token->[2]->{'include'};
 	my $exclude = $token->[2]->{'exclude'};
-        my @preferred_languages=&Apache::loncommon::preferred_languages();
+        my @preferred_languages=&Apache::lonlocal::preferred_languages();
 # This should not even happen, since we should at least have the server language
         if (!$preferred_languages[0]) { $preferred_languages[0]='en'; }
 # Now loop over all languages in order of preference
@@ -1896,20 +1906,21 @@ sub end_startouttext {
     if ($target eq 'edit') {
 	my $areaid = 'homework_edit_'.$Apache::lonxml::curdepth;
 	$text=&Apache::lonxml::get_all_text("endouttext",$parser,$style);
-	$result.=&Apache::edit::start_table($token)."<tr><td>".&mt('Text Block')."</td>
-<td>".&mt('Delete:').
-                 &Apache::edit::deletelist($target,$token)
-		 ."</td>";
+
+	$result.=&Apache::edit::start_table($token)."<tr><td>".&mt('Text Block')."</td>"
+                 .'<td><span clas="LC_nobreak">'.&mt('Delete?').' '
+                 .&Apache::edit::deletelist($target,$token)
+                 .'</span></td>';
         unless ($env{'environment.wysiwygeditor'} eq 'on') {
-            $result.='<td align="left">'
-                     .&Apache::lonhtmlcommon::dragmath_button($areaid,1)
-		     .'</td>'
-                     .'<td>'
-                     .&Apache::edit::insertlist($target,$token)
-		     .'</td>';
-        }
+	    $result .= '<td align="left">'
+		.&Apache::lonhtmlcommon::dragmath_button($areaid,1)
+		.'</td>'
+		.'<td>'
+		.&Apache::edit::insertlist($target,$token)
+		.'</td>';
+	}
 	$result.='<td align="right" valign="top">' .
-		 &Apache::loncommon::helpLatexCheatsheet().
+	    &Apache::loncommon::helpLatexCheatsheet().
 		 &Apache::edit::end_row().
                  &Apache::edit::start_spanning_row()."\n".
 		 &Apache::edit::editfield($token->[1],$text,"",80,8,1);
