@@ -3,7 +3,7 @@
 # institutional log-in ID (institutional authentication required - localauth
 #  or kerberos) or an e-mail address.
 #
-# $Id: createaccount.pm,v 1.26 2008/12/05 19:22:58 schafran Exp $
+# $Id: createaccount.pm,v 1.32 2009/03/14 02:04:22 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -58,10 +58,21 @@ sub handler {
     my $sso_username = $r->subprocess_env->get('REDIRECT_SSOUserUnknown');
     my $sso_domain = $r->subprocess_env->get('REDIRECT_SSOUserDomain');
 
+    &Apache::loncommon::get_unprocessed_cgi($ENV{'QUERY_STRING'},['token','courseid']);
+    &Apache::lonacc::get_posted_cgi($r);
+    &Apache::lonlocal::get_language_handle($r);
+
     if ($sso_username ne '' && $sso_domain ne '') {
         $domain = $sso_domain; 
-    } else { 
+    } else {
         $domain = &Apache::lonnet::default_login_domain();
+        if (defined($env{'form.courseid'})) {
+            if (&validate_course($env{'form.courseid'})) {
+                if ($env{'form.courseid'} =~ /^($match_domain)_($match_courseid)$/) {
+                    $domain = $1; 
+                }
+            }
+        }
     }
     my $domdesc = &Apache::lonnet::domain($domain,'description');
     my $contact_name = &mt('LON-CAPA helpdesk');
@@ -74,12 +85,8 @@ sub handler {
     my $include = $r->dir_config('lonIncludes');
     my $start_page;
 
-    &Apache::loncommon::get_unprocessed_cgi($ENV{'QUERY_STRING'},['token','courseid']);
-    &Apache::lonacc::get_posted_cgi($r);
-    &Apache::lonlocal::get_language_handle($r);
-
     my $handle = &Apache::lonnet::check_for_valid_session($r);
-    if ($handle ne '') {
+    if (($handle ne '') && ($handle !~ /^publicuser_\d+$/)) {
         $start_page =
             &Apache::loncommon::start_page('Already logged in');
         my $end_page =
@@ -306,9 +313,10 @@ sub validate_course {
 sub javascript_setforms {
     my ($now) =  @_;
     my $js = <<ENDSCRIPT;
- <script language="JavaScript">
+ <script type="text/javascript" language="JavaScript">
     function send() {
         this.document.server.elements.uname.value = this.document.client.elements.uname.value;
+        this.document.server.elements.udom.value = this.document.client.elements.udom.value;
         uextkey=this.document.client.elements.uextkey.value;
         lextkey=this.document.client.elements.lextkey.value;
         initkeys();
@@ -339,16 +347,16 @@ sub javascript_checkpass {
         var upasscheck = this.document.client.elements.upasscheck$now.value;
         if (upass == '') {
             alert("$nopass");
-            return;
+            return false;
         }
         if (upass == upasscheck) {
             this.document.client.elements.upasscheck$now.value='';
             send();
-            return;
+            return false;
         } else {
             alert("$mismatchpass");
-            return;
-        } 
+            return false;
+        }
     }
 </script>
 ENDSCRIPT
@@ -397,34 +405,45 @@ sub print_username_form {
         }
         if (grep(/^email$/,@{$cancreate})) {
             $output .= '<div class="LC_left_float"><h3>'.&mt('Create account with an e-mail address as your username').'</h3>';
-            if (grep(/^login$/,@{$cancreate})) {
-                $output .= &mt('Provide your e-mail address to request a LON-CAPA account,[_1] if you do not have a log-in ID at your institution.','<br />').'<br /><br />';
-            } else {
-                $output .= '<br />';
-            }
-            my $emailform = '<input type="text" name="useremail" size="25" value="" />';
             my $captchaform = &create_captcha();
-            my $submit_text = &mt('Request LON-CAPA account');
-            $output .=  '<form name="createaccount" method="post" onSubmit="return validate_email()" action="/adm/createaccount">'.
-                        &Apache::lonhtmlcommon::start_pick_box()."\n".
-                        &Apache::lonhtmlcommon::row_title(&mt('E-mail address'),
-                                                         'LC_pick_box_title')."\n".
-                        $emailform."\n".
-                        &Apache::lonhtmlcommon::row_closure(1).
-                        &Apache::lonhtmlcommon::row_title(&mt('Validation'),
-                                                         'LC_pick_box_title')."\n".
-                        $captchaform."\n".'<br /><br />';
-            if ($courseid ne '') {
-                $output .= '<input type="hidden" name="courseid" value="'.$courseid.'"/>'."\n"; 
+            if ($captchaform) {
+                my $submit_text = &mt('Request LON-CAPA account');
+                my $emailform = '<input type="text" name="useremail" size="25" value="" />';
+                if (grep(/^login$/,@{$cancreate})) {
+                    $output .= &mt('Provide your e-mail address to request a LON-CAPA account,[_1] if you do not have a log-in ID at your institution.','<br />').'<br /><br />';
+                } else {
+                    $output .= '<br />';
+                }
+                $output .=  '<form name="createaccount" method="post" onSubmit="return validate_email()" action="/adm/createaccount">'.
+                            &Apache::lonhtmlcommon::start_pick_box()."\n".
+                            &Apache::lonhtmlcommon::row_title(&mt('E-mail address'),
+                                                             'LC_pick_box_title')."\n".
+                            $emailform."\n".
+                            &Apache::lonhtmlcommon::row_closure(1).
+                            &Apache::lonhtmlcommon::row_title(&mt('Validation'),
+                                                             'LC_pick_box_title')."\n".
+                            $captchaform."\n".'<br /><br />';
+                if ($courseid ne '') {
+                    $output .= '<input type="hidden" name="courseid" value="'.$courseid.'"/>'."\n"; 
+                }
+                $output .=  &Apache::lonhtmlcommon::row_closure(1).
+                            &Apache::lonhtmlcommon::row_title().'<br />'.
+                            '<input type="submit" name="create_with_email" value="'. 
+                            $submit_text.'" />'.
+                            &Apache::lonhtmlcommon::row_closure(1).
+                            &Apache::lonhtmlcommon::end_pick_box().'<br /><br />';
+                if ($courseid ne '') {
+                    $output .= &Apache::lonhtmlcommon::echo_form_input(['courseid']);
+                }
+                $output .= '</form>';
+            } else {
+                my $helpdesk = '/adm/helpdesk?origurl=%2fadm%2fcreateaccount';
+                if ($courseid ne '') {
+                    $helpdesk .= '&courseid='.$courseid;
+                }
+                $output .= '<span class="LC_error">'.&mt('An error occurred generating the validation code[_1] required for an e-mail address to be used as username.','<br />').'</span><br /><br />'.&mt('[_1]Contact the helpdesk[_2] or [_3]reload[_2] the page and try again.','<a href="'.$helpdesk.'">','</a>','<a href="javascript:window.location.reload()">');
             }
-            $output .= '<input type="submit" name="create_with_email" value="'. 
-                        $submit_text.'" />'.
-                        &Apache::lonhtmlcommon::row_closure(1).
-                        &Apache::lonhtmlcommon::end_pick_box().'<br /><br />';
-            if ($courseid ne '') {
-                $output .= &Apache::lonhtmlcommon::echo_form_input(['courseid']);
-            }
-            $output .= '</form></div>';
+            $output .= '</div>';
         }
     }
     if ($output eq '') {
@@ -447,31 +466,40 @@ sub login_box {
     my $logtoken=Apache::lonnet::reply('tmpput:'.$ukey.$lkey.'&createaccount',
                                        $lonhost);
     $output = &serverform($logtoken,$lonhost,undef,$courseid,$context);
-    my $unameform = '<input type="text" name="uname" size="10" value="" />';
-    my $upassform = '<input type="password" name="upass'.$now.'" size="10" />';
-    $output .= '<form name="client" method="post" action="/adm/createaccount">'."\n".
-               &Apache::lonhtmlcommon::start_pick_box()."\n";
-    if ($context eq 'selfenroll') {
-        my $udomform =  '<input type="text" name="udom" size="10" value="'.
-                        $domain.'" />';
-        $output .= &Apache::lonhtmlcommon::row_title(&mt('Domain'),
-                                                     'LC_pick_box_title')."\n".
-                   $udomform."\n".
-                   &Apache::lonhtmlcommon::row_closure(1)."\n";
-    }
-
-    $output .= &Apache::lonhtmlcommon::row_title($titles{$context},
+    my $unameform = '<input type="text" name="uname" size="20" value="" />';
+    my $upassform = '<input type="password" name="upass'.$now.'" size="20" />';
+    $output .= '<form name="client" method="post" onsubmit="return(send());">'."\n".
+               &Apache::lonhtmlcommon::start_pick_box()."\n".
+               &Apache::lonhtmlcommon::row_title($titles{$context},
                                                  'LC_pick_box_title')."\n".
                $unameform."\n".
                &Apache::lonhtmlcommon::row_closure(1)."\n".
                &Apache::lonhtmlcommon::row_title(&mt('Password'),
                                                 'LC_pick_box_title')."\n".
-               $upassform."\n".'<br /><br />'."\n".
-               '<input type="button" name="username_validation" value="'.
-               $submit_text.'" onclick="javascript:send()" />'."\n".
-               &Apache::lonhtmlcommon::row_closure(1)."\n".
-               &Apache::lonhtmlcommon::end_pick_box().'<br /><br />'."\n".
-               '<input type="hidden" name="lextkey" value="'.$lextkey.'">'."\n".
+               $upassform;
+    if ($context eq 'selfenroll') {
+        my $udomform = '<input type="text" name="udom" size="10" value="'.
+                        $domain.'" />';
+        $output .= &Apache::lonhtmlcommon::row_closure(1)."\n".
+                   &Apache::lonhtmlcommon::row_title(&mt('Domain'),
+                                                     'LC_pick_box_title')."\n".
+                   $udomform."\n";
+    } else {
+        $output .= '<input type="hidden" name="udom" value="'.$domain.'" />';
+    }
+    $output .= &Apache::lonhtmlcommon::row_closure(1).
+               &Apache::lonhtmlcommon::row_title().
+               '<br /><input type="submit" name="username_validation" value="'.
+               $submit_text.'" />'."\n";
+    if ($context eq 'selfenroll') {
+        $output .= '<br /><br /><table width="100%"><tr><td align="right">'.
+                   '<span class="LC_fontsize_medium">'.
+                   '<a href="/adm/resetpw">'.&mt('Forgot password?').'</a>'.
+                   '</span></td></tr></table>'."\n";
+    }
+    $output .= &Apache::lonhtmlcommon::row_closure(1)."\n".
+               &Apache::lonhtmlcommon::end_pick_box().'<br />'."\n";
+    $output .= '<input type="hidden" name="lextkey" value="'.$lextkey.'">'."\n".
                '<input type="hidden" name="uextkey" value="'.$uextkey.'">'."\n".
                '</form>';
     return $output;
@@ -576,10 +604,10 @@ sub send_token {
     my $token = &Apache::lonnet::tmpput(\%info,$server);
     if ($token !~ /^error/ && $token ne 'no_such_host') {
         my $esc_token = &escape($token);
-        my $mailmsg = &mt('A request was submitted on [_1] for creation of a LON-CAPA account at the following institution: [_2].',localtime(time),$domdesc).' '.
-             &mt('To complete this process please open a web browser and enter the following'
-                .' URL in the address/location box: [_1]'
-                ,&Apache::lonnet::absolute_url().'/adm/createaccount?token='.$esc_token);
+        my $showtime = localtime(time);
+        my $mailmsg = &mt('A request was submitted on [_1] for creation of a LON-CAPA account at the following institution: [_2].',$showtime,$domdesc).' '.
+             &mt('To complete this process please open a web browser and enter the following URL in the address/location box: [_1]',
+                 &Apache::lonnet::absolute_url().'/adm/createaccount?token='.$esc_token);
         my $result = &Apache::resetpw::send_mail($domdesc,$email,$mailmsg,$contact_name,
                                                  $contact_email);
         if ($result eq 'ok') {
@@ -699,79 +727,65 @@ sub print_dataentry_form {
         my ($lextkey,$uextkey) = &getkeys($lkey,$ukey);
         my $logtoken=Apache::lonnet::reply('tmpput:'.$ukey.$lkey.'&createaccount',
                                            $lonhost);
-        my @userinfo = ('firstname','middlename','lastname','generation','id',
-                        'permanentemail');
-        my %lt=&Apache::lonlocal::texthash(
-                    'pd'             => "Personal Data",
-                    'firstname'      => "First Name",
-                    'middlename'     => "Middle Name",
-                    'lastname'       => "Last Name",
-                    'generation'     => "Generation",
-                    'permanentemail' => "Permanent e-mail address",
-                    'id'             => "Student/Employee ID",
-                    'lg'             => "Login Data"
-        );
-        my %textboxsize = (
-                           firstname      => '15',
-                           middlename     => '15',
-                           lastname       => '15',
-                           generation     => '5',
-                           id             => '15',
-                          );
-        my $genhelp=&Apache::loncommon::help_open_topic('Generation');
-        $output .= '<div class="LC_left_float"><h3>'.$lt{'pd'}.'</h3>'.
-                  '<form name="server" method="post" target="_top" action="/adm/createaccount">'.
-                  &Apache::lonhtmlcommon::start_pick_box();
-        foreach my $item (@userinfo) {
-            my $rowtitle = $lt{$item};
-            if ($item eq 'generation') {
-                $rowtitle = $genhelp.$rowtitle;
-            }
-            $output .= &Apache::lonhtmlcommon::row_title($rowtitle,undef,'LC_oddrow_value')."\n";
-            if ($item eq 'permanentemail') {
-                $output .= $username;
-            } else {
-                $output .= '<input type="text" name="c'.$item.'" size="'.$textboxsize{$item}.'" value="" />';
-            }
-            $output .= &Apache::lonhtmlcommon::row_closure(1);
+        my $formtag = '<form name="server" method="post" target="_top" action="/adm/createaccount">';
+        my ($datatable,$rowcount) =
+            &Apache::loncreateuser::personal_data_display($username,$domain,
+                                                          'email','selfcreate');
+        if ($rowcount) {
+            $output .= '<div class="LC_left_float">'.$formtag.$datatable;
+        } else {
+            $output .= $formtag;
         }
-        $output .= &Apache::lonhtmlcommon::end_pick_box();
         $output .= <<"ENDSERVERFORM";
    <input type="hidden" name="logtoken" value="$logtoken" />
    <input type="hidden" name="token" value="$mailtoken" />
    <input type="hidden" name="serverid" value="$lonhost" />
    <input type="hidden" name="uname" value="" />
    <input type="hidden" name="upass" value="" />
+   <input type="hidden" name="udom" value="" />
    <input type="hidden" name="phase" value="createaccount" />
-  </form></div>
+  </form>
 ENDSERVERFORM
+        if ($rowcount) {
+            $output .= '</div>'.
+                       '<div class="LC_left_float">';
+        }
         my $upassone = '<input type="password" name="upass'.$now.'" size="10" />';
         my $upasstwo = '<input type="password" name="upasscheck'.$now.'" size="10" />';
         my $submit_text = &mt('Create LON-CAPA account');
-        $output .= '<div class="LC_left_float"><h3>'.$lt{'lg'}.'</h3>'."\n".
-                   '<form name="client" method="post" />'."\n".
+        $output .= '<h3>'.&mt('Login Data').'</h3>'."\n".
+                   '<form name="client" method="post" '.
+                   'onsubmit="return checkpass();">'."\n".
                    &Apache::lonhtmlcommon::start_pick_box()."\n".
                    &Apache::lonhtmlcommon::row_title(&mt('Username'),
-                                                    'LC_pick_box_title')."\n".
+                                                     'LC_pick_box_title',
+                                                     'LC_oddrow_value')."\n".
                    $username."\n".
                    &Apache::lonhtmlcommon::row_closure(1)."\n".
                    &Apache::lonhtmlcommon::row_title(&mt('Password'),
-                                                    'LC_pick_box_title')."\n".
+                                                    'LC_pick_box_title',
+                                                    'LC_oddrow_value')."\n".
                    $upassone."\n".
                    &Apache::lonhtmlcommon::row_closure(1)."\n".
                    &Apache::lonhtmlcommon::row_title(&mt('Confirm password'),
-                                                'LC_pick_box_title')."\n".
-                   $upasstwo."\n".
+                                                     'LC_pick_box_title',
+                                                     'LC_oddrow_value')."\n".
+                   $upasstwo.
+                   &Apache::lonhtmlcommon::row_closure(1)."\n".
+                   &Apache::lonhtmlcommon::row_title()."\n".
+                   '<br /><input type="submit" name="createaccount" value="'.
+                   $submit_text.'" />'.
                    &Apache::lonhtmlcommon::row_closure(1)."\n".
                    &Apache::lonhtmlcommon::end_pick_box()."\n".
-                   '<input type="hidden" name="uname" value="'.$username.'">'."\n".
-                   '<input type="hidden" name="lextkey" value="'.$lextkey.'">'."\n".
-                   '<input type="hidden" name="uextkey" value="'.$uextkey.'">'."\n".
-                   '</form></div>'."\n".
-                   '<div class="LC_clear_float_footer"><br /><br />'."\n".
-                   '<form name="buttonform">'."\n".
-                   '<input type="button" name="createaccount" value="'.
-                   $submit_text.'" onclick="javascript:checkpass();" /></form></div>';
+                   '<input type="hidden" name="uname" value="'.$username.'" />'."\n".
+                   '<input type="hidden" name="udom" value="'.$domain.'" />'."\n".
+                   '<input type="hidden" name="lextkey" value="'.$lextkey.'" />'."\n".
+                   '<input type="hidden" name="uextkey" value="'.$uextkey.'" />'."\n".
+                   '</form>';
+        if ($rowcount) {
+            $output .= '</div>'."\n".
+                       '<div class="LC_clear_float_footer"></div>'."\n";
+        }
     } else {
         $output = &mt('Could not load javascript file [_1]','<tt>londes.js</tt>');
     }
@@ -1115,15 +1129,23 @@ sub linkto_email_help {
 sub create_captcha {
     my ($output_dir,$db_dir) = @_;
     my %captcha_params = &captcha_settings();
-    my $captcha = Authen::Captcha->new(
-                                       output_folder => $captcha_params{'output_dir'},
-                                       data_folder   => $captcha_params{'db_dir'},
-                                      );
-    my $md5sum = $captcha->generate_code($captcha_params{'numchars'});
-    my $output = '<input type="hidden" name="crypt" value="'.$md5sum.'" />'."\n".
-                 &mt('Type in the letters/numbers shown below').'&nbsp;'.
-                 '<input type="text" size="5" name="code" value="" /><br />'.
-                 '<img src="'.$captcha_params{'www_output_dir'}.'/'.$md5sum.'.png">';
+    my ($output,$maxtries,$tries) = ('',10,0);
+    while ($tries < $maxtries) {
+        $tries ++;
+        my $captcha = Authen::Captcha->new (
+                                           output_folder => $captcha_params{'output_dir'},
+                                           data_folder   => $captcha_params{'db_dir'},
+                                          );
+        my $md5sum = $captcha->generate_code($captcha_params{'numchars'});
+
+        if (-e $Apache::lonnet::perlvar{'lonCaptchaDir'}.'/'.$md5sum.'.png') {
+            $output = '<input type="hidden" name="crypt" value="'.$md5sum.'" />'."\n".
+                      &mt('Type in the letters/numbers shown below').'&nbsp;'.
+                     '<input type="text" size="5" name="code" value="" /><br />'.
+                     '<img src="'.$captcha_params{'www_output_dir'}.'/'.$md5sum.'.png">';
+            last;
+        }
+    }
     return $output;
 }
 
@@ -1164,6 +1186,7 @@ sub serverform {
    <input type="hidden" name="serverid" value="$lonhost" />
    <input type="hidden" name="uname" value="" />
    <input type="hidden" name="upass" value="" />
+   <input type="hidden" name="udom" value="" />
    <input type="hidden" name="phase" value="$phase" />
    <input type="hidden" name="courseid" value="$courseid" />
    $catalog_elements
