@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # "About Me" Personal Information
 #
-# $Id: lonaboutme.pm,v 1.70.2.2 2008/12/17 23:05:11 raeburn Exp $
+# $Id: lonaboutme.pm,v 1.70.2.3 2009/03/18 03:14:18 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -313,7 +313,7 @@ sub handler {
 			  ('View recent activity by this student',
 			   $cnum,$cdom).('&nbsp;'x2));
 	    }
-	    $r->print(&Apache::loncommon::noteswrapper('Add Records',$cnum,$cdom));
+	    $r->print(&Apache::loncommon::noteswrapper(&mt('Add Records'),$cnum,$cdom));
 	} else {
 	    $r->print('\\\\\textbf{'.&mt('User Notes, Records of Face-To-Face Discussions, and Critical Messages in Course').'}\\\\'.&mt('Shared by course faculty and staff').'\\\\\\\\');
 	    &Apache::lonmsgdisplay::disfacetoface($r,$cnum,$cdom);
