@@ -1,6 +1,6 @@
 # The LearningOnline Network with CAPA
 #
-# $Id: lonhelp.pm,v 1.37 2008/02/26 09:28:07 bisitz Exp $
+# $Id: lonhelp.pm,v 1.39 2008/07/08 01:08:57 raeburn Exp $
 #
 # .tex help system web server handler
 #
@@ -119,7 +119,7 @@ sub render {
              '\\begin{html}<a href="/adm/help/'.
               $label .
               '.hlp#' . &processLabelName($1) . 
-             '"><img src="/adm/help/gif/smallHelp.gif" border="0" /></a>' .
+             '"><img src="/adm/help/help.png" border="0" /></a>' .
              '\\end{html}'
              |gxe;
 
