@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # a pile of common html routines
 #
-# $Id: lonhtmlcommon.pm,v 1.182 2008/10/07 10:13:58 foxr Exp $
+# $Id: lonhtmlcommon.pm,v 1.182.2.1 2009/01/12 01:53:38 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -1278,6 +1278,9 @@ Inputs: $component (the large text on the right side of the table),
         $menulink (boolean, controls whether to include a link to /adm/menu)
         $helplink (if 'nohelp' don't include the orange help link)
         $css_class (optional name for the class to apply to the table for CSS)
+        $no_mt (optional flag, 1 if &mt() is _not_ to be applied to $component
+           when including the text on the right.
+
 Returns a string containing breadcrumbs for the current page.
 
 =item clear_breadcrumbs
@@ -1303,7 +1306,7 @@ returns: nothing
     my @Crumbs;
     
     sub breadcrumbs {
-        my ($component,$component_help,$menulink,$helplink,$css_class) = @_;
+        my ($component,$component_help,$menulink,$helplink,$css_class,$no_mt) = @_;
         #
 	$css_class ||= 'LC_breadcrumbs';
         my $Str = "\n".'<table class="'.$css_class.'"><tr><td>';
@@ -1383,8 +1386,12 @@ returns: nothing
         $Str .= $links.'</td>';
         #
         if (defined($component)) {
-            $Str .= '<td class="'.$css_class.'_component">'.
-                &mt($component);
+            $Str .= '<td class="'.$css_class.'_component">';
+            if ($no_mt) {
+                $Str .= $component;
+            } else {
+                $Str .= &mt($component);
+            }
 	    if ($icons ne '') {
 		$Str .= '&nbsp;'.$icons;
 	    }
