@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Directory Indexer
 #
-# $Id: lonindexer.pm,v 1.181 2008/08/01 14:53:42 bisitz Exp $
+# $Id: lonindexer.pm,v 1.181.2.2 2008/12/17 18:49:13 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -542,8 +542,8 @@ END
 	$r->print("<td $colspan><b>".&mt('Name')."</b></td>\n");
 	$r->print("<td><b>".&mt('Title')."</b></td>\n") 
 	    if ($hash{'display_attrs_0'} == 1);
-	$r->print("<td align=right><b>".&mt("Size")." (".&mt("bytes").") ".
-		  "</b></td>\n") if ($hash{'display_attrs_1'} == 1);
+	$r->print('<td align="right"><b>'.&mt('Size').' ('.&mt('bytes').') '.
+		  '</b></td>'."\n") if ($hash{'display_attrs_1'} == 1);
 	$r->print("<td><b>".&mt("Last accessed")."</b></td>\n") 
 	    if ($hash{'display_attrs_2'} == 1);
 	$r->print("<td><b>".&mt("Last modified")."</b></td>\n")
@@ -944,7 +944,8 @@ sub display_line {
         }
 	# Set the icon for the file
 	my $iconname = &Apache::loncommon::icon($listname);
-	$r->print("<tr valign='$valign' bgcolor=\"$fileclr\"><td nowrap='nowrap' valign='top'>");
+	$r->print('<tr valign="'.$valign.'" bgcolor="'.$fileclr.'">'.
+                  '<td valign="top"><span class="LC_nobreak">');
 	
         if ($env{'form.catalogmode'} eq 'interactive') {
 	    my $quotable_filelink = &Apache::loncommon::escape_single($filelink);
@@ -952,7 +953,7 @@ sub display_line {
                       $quotable_filelink,"')\">");
 	    $r->print("<img alt=\"\" src='",$iconpath,"select.gif' class='LC_icon' /></a>".
 		      "\n");
-	    $r->print("</td><td nowrap='nowrap' valign='top'>");
+	    $r->print('</span></td><td valign="top"><span class="LC_nobreak">');
 	} elsif ($env{'form.catalogmode'} eq 'import') {
 	    $r->print("<form name='form$fnum' action=''>\n");
 	    $r->print("<input type='checkbox' name='filelink"."' ".
@@ -962,7 +963,7 @@ sub display_line {
 		$r->print("checked");
 	    }
 	    $r->print(" />\n");
-	    $r->print("</form></td><td nowrap='nowrap' valign='top'>");
+	    $r->print('</form></span></td><td valign="top"><span class="LC_nobreak">');
 	    $hash{"pre_${fnum}_link"}=$filelink;
 	    $hash{"pre_${fnum}_title"}=$title;
 	    if (!$hash{"pre_${fnum}_title"}) {
@@ -1019,12 +1020,12 @@ sub display_line {
 	if ($filelink=~/\.(page|sequence)$/) {
 	    $r->print('</form>');
 	}
-	$r->print("</td>\n");
+	$r->print("</span></td>\n");
 	if ($hash{'display_attrs_0'} == 1) {
 	    $r->print('<td> '.($title eq '' ? '&nbsp;' : $title).
 		      ' </td>'."\n");
 	}
-	$r->print('<td align=right> ',
+	$r->print('<td align="right"> ',
 		  $filecom[8]," </td>\n") 
 	    if $hash{'display_attrs_1'} == 1;
 	$r->print('<td> '.
@@ -1149,7 +1150,7 @@ sub display_line {
 	    $r->print('<td> '.($title eq '' ? '&nbsp;' : $title).
 		      ' </td>'."\n");
 	}
-	$r->print('<td align=right> ',
+	$r->print('<td align="right"> ',
 		  $filecom[8]," </td>\n") 
 	    if $hash{'display_attrs_1'} == 1;
 	$r->print('<td> '.
