@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Handler for requesting to have slots added to a students record
 #
-# $Id: slotrequest.pm,v 1.85 2008/12/21 04:14:39 raeburn Exp $
+# $Id: slotrequest.pm,v 1.88.2.1 2009/05/17 21:03:16 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -345,8 +345,8 @@ sub remove_registration {
 	return;
     }
     if (!%consumed) {
-	$r->print("<p>".&mt('Slot <tt>[_1]</tt> has no reservations.',
-			    $slot_name)."</p>");
+	$r->print('<p>'.&mt('Slot [_1] has no reservations.',
+			    '<tt>'.$slot_name.'</tt>').'</p>');
 	return;
     }
 
@@ -557,15 +557,15 @@ sub delete_slot {
 	my $ret = &Apache::lonnet::cput('slots', {$slot_name => \%slot},
 					$cdom, $cnum);
 	if ($ret eq 'ok') {
-	    $r->print("<p>Slot <tt>$slot_name</tt> marked as deleted.</p>");
+	    $r->print('<p>'.&mt('Slot [_1] marked as deleted.','<tt>'.$slot_name.'</tt>').'</p>');
 	} else {
-	    $r->print("<p><span class=\"LC_error\"> An error ($ret) occurse when attempting to delete Slot <tt>$slot_name</tt>.</span></p>");
+	    $r->print('<p><span class="LC_error">'.&mt('An error occurred when attempting to delete slot: [_1]','<tt>'.$slot_name.'</tt>')." ($ret)</span></p>");
 	}
     } else {
 	if (%consumed) {
-	    $r->print("<p>Slot <tt>$slot_name</tt> has active reservations.</p>");
+	    $r->print('<p>'.&mt('Slot [_1] has active reservations.','<tt>'.$slot_name.'</tt>').'</p>');
 	} else {
-	    $r->print("<p>Slot <tt>$slot_name</tt> does not exist.</p>");
+	    $r->print('<p>'.&mt('Slot [_1] does not exist.','<tt>'.$slot_name.'</tt>').'</p>');
 	}
     }
     $r->print('<p><a href="/adm/slotrequest?command=showslots">'.
@@ -597,7 +597,7 @@ sub get_slot {
 	my $description1=&get_description($slot_name,\%slot);
 	%slot=&Apache::lonnet::get_slot($env{'form.slotname'});
 	my $description2=&get_description($env{'form.slotname'},\%slot);
-	$r->print("<p>Already have a reservation: $description1</p>");
+	$r->print('<p>'.&mt('Already have a reservation: [_1].',$description1).'</p>');
 	if ($slot_name ne $env{'form.slotname'}) {
 	    $r->print(<<STUFF);
 <form method="post" action="/adm/slotrequest">
@@ -606,13 +606,14 @@ sub get_slot {
    <input type="hidden" name="releaseslot" value="$slot_name" />
    <input type="hidden" name="command" value="change" />
 STUFF
-            $r->print("<p>You can either ");
-	    $r->print(<<STUFF);
-   <input type="submit" name="change" value="Change" />
-STUFF
-	    $r->print(' your reservation from <b>'.$description1.'</b> to <b>'.
-		      $description2.
-		      '</b> <br />or </p>');
+            $r->print('<p>'
+                     .&mt('You can either [_1]Change[_2] your reservation from [_3] to [_4] or'
+                         ,'<input type="submit" name="change" value="'
+                         ,'" />'
+                         ,'<b>'.$description1.'</b>'
+                         ,'<b>'.$description2.'</b>')
+                     .'<br /></p>'
+            );
 	    &return_link($r);
 	    $r->print(<<STUFF);
 </form>
@@ -633,17 +634,18 @@ STUFF
                      .&mt('An error occurred while attempting to make a reservation. ([_1])',$1)
                      .'</span></p>');
 	} elsif ($reserved > -1) {
-	    $r->print("<p>Success: $description</p>");
+	    $r->print('<p>'.&mt('Success: [_1]',$description).'</p>');
 	    $retvalue = 1;
 	} elsif ($reserved < 0) {
-	    $r->print("<p>Already reserved: $description</p>");
+	    $r->print('<p>'.&mt('Already reserved: [_1]',$description).'</p>');
 	}
 	if (!$inhibit_return_link) { &return_link($r); }
 	return 1;
     }
 
     my %lt=('request'=>"Availibility list",
-	    'try'    =>'Try again');
+	    'try'    =>'Try again?',
+            'or'     => 'or');
     %lt=&Apache::lonlocal::texthash(%lt);
 
     my $extra_input;
@@ -651,8 +653,8 @@ STUFF
 	$extra_input='<input type="hidden" name="releaseslot" value="'.$env{'form.slotname'}.'" />';
     }
 
+    $r->print('<p>'.&mt('[_1]Failed[_2] to reserve a slot for [_3].','<span class="LC_warning">','</span>',$description).'</p>');
     $r->print(<<STUFF);
-<p> <span class="LC_warning">Failed</span> to reserve a spot for $description. </p>
 <p>
 <form method="post" action="/adm/slotrequest">
    <input type="submit" name="Try Again" value="$lt{'try'}" />
@@ -661,19 +663,21 @@ STUFF
    <input type="hidden" name="command" value="$env{'form.command'}" />
    $extra_input
 </form>
-?
 </p>
 <p>
-or
+$lt{'or'}
 <form method="post" action="/adm/slotrequest">
     <input type="hidden" name="symb" value="$env{'form.symb'}" />
     <input type="submit" name="requestattempt" value="$lt{'request'}" />
 </form>
-</p>
-or
 STUFF
 
-    if (!$inhibit_return_link) { &return_link($r); }
+    if (!$inhibit_return_link) { 
+        $r->print(&mt('or').'</p>');
+        &return_link($r);
+    } else {
+        $r->print('</p>');
+    }
     return 0;
 }
 
@@ -756,7 +760,7 @@ sub allowed_slot {
 				       $consumed_uniqueperiods);
     if ($conflict =~ /^error: /) {
         return 0;
-    } else {
+    } elsif ($conflict ne '') {
 	if ($slots->{$conflict}{'starttime'} < time) {
 	    return 0;
 	}
@@ -859,7 +863,8 @@ STUFF
     }
 
     if (!$available) {
-	$r->print('<tr><td>No available times. <a href="/adm/flip?postdata=return:">'.
+	$r->print('<tr><td>'.&mt('No available times.').
+                  ' <a href="/adm/flip?postdata=return:">'.
 		  &mt('Return to last resource').'</a></td></tr>');
     }
     $r->print('</table>');
@@ -1346,7 +1351,7 @@ sub upload_start {
     $result.='&nbsp;<b>'.
 	&mt('Specify a file containing the slot definitions.').
 	'</b></td></tr>'."\n";
-    $result.='<tr bgcolor=#ffffe6><td>'."\n";
+    $result.='<tr bgcolor="#ffffe6"><td>'."\n";
     my $upfile_select=&Apache::loncommon::upfile_select_html();
     my $ignore=&mt('Ignore First Line');
     $result.=<<ENDUPFORM;
@@ -1401,11 +1406,12 @@ ENDPICK
 
 sub csvuploadmap_footer {
     my ($request,$i,$keyfields) =@_;
+    my $buttontext = &mt('Create Slots');
     $request->print(<<ENDPICK);
 </table>
 <input type="hidden" name="nfields" value="$i" />
 <input type="hidden" name="keyfields" value="$keyfields" />
-<input type="button" onClick="javascript:verify(this.form)" value="Create Slots" /><br />
+<input type="button" onClick="javascript:verify(this.form)" value="$buttontext" /><br />
 </form>
 ENDPICK
 }
@@ -1522,7 +1528,7 @@ sub csv_upload_assign {
     my @slotdata = &Apache::loncommon::upfile_record_sep();
     if ($env{'form.noFirstLine'}) { shift(@slotdata); }
     my %fields=&Apache::grades::get_fields();
-    $r->print('<h3>Creating Slots</h3>');
+    $r->print('<h3>'.&mt('Creating Slots').'</h3>');
     my $cname=$env{'course.'.$env{'request.course.id'}.'.num'};
     my $cdom=$env{'course.'.$env{'request.course.id'}.'.domain'};
     my $countdone=0;
@@ -1609,9 +1615,9 @@ sub csv_upload_assign {
 	$r->rflush();
 	$countdone++;
     }
-    $r->print("<p>Created $countdone slots\n</p>");
+    $r->print('<p>'.&mt('Created [quant,_1,slot]',$countdone)."\n".'</p>');
     foreach my $error (@errors) {
-	$r->print("<p><span class=\"LC_warning\">$error</span></p>\n");
+	$r->print('<p><span class="LC_warning">'.$error.'</span></p>'."\n");
     }
     &show_table($r,$mgr);
     return '';
@@ -1699,7 +1705,7 @@ sub handler {
 		&release_slot($r,$symb,$env{'form.releaseslot'});
 	    }
 	} else {
-	    $r->print("<p>Unknown command: ".$env{'form.command'}."</p>");
+	    $r->print('<p>'.&mt('Unknown command: [_1]',$env{'form.command'}).'</p>');
 	}
     }
     &end_page($r);
