@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Construct and maintain state and binary representation of course for user
 #
-# $Id: lonuserstate.pm,v 1.128.2.1 2008/12/21 04:46:53 raeburn Exp $
+# $Id: lonuserstate.pm,v 1.128.2.2 2009/03/21 06:12:05 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -573,7 +573,8 @@ sub accinit {
     $acchash{'acc.res.'.$short.'.'}='&:0&';
     my $courseuri=$uri;
     $courseuri=~s/^\/res\///;
-    &Apache::lonnet::delenv('(acc\.|httpref\.)');
+    my $regexp = 1;
+    &Apache::lonnet::delenv('(acc\.|httpref\.)',$regexp);
     &Apache::lonnet::appenv(\%acchash);
 }
 
